@@ -3,7 +3,7 @@ import logging
 
 from weconnect.addressable import AddressableLeaf, ChangeableAttribute, AddressableAttribute, AliasChangeableAttribute
 from weconnect.elements.generic_settings import GenericSettings
-from weconnect.util import toBool
+from weconnect.util import toBool, celsiusToKelvin, farenheitToKelvin
 
 LOG = logging.getLogger("weconnect")
 
@@ -17,12 +17,6 @@ class ClimatizationSettings(GenericSettings):
         fromDict=None,
         fixAPI=True,
     ):
-        def celsiusToKelvin(value):
-            return value + 273.15
-
-        def farenheitToKelvin(value):
-            return 273.5 + ((value - 32.0) * (5.0 / 9.0))
-
         self.targetTemperature_K = ChangeableAttribute(
             localAddress='targetTemperature_K', parent=self, value=None, valueType=float)
         self.targetTemperature_C = AliasChangeableAttribute(localAddress='targetTemperature_C', parent=self, value=None,
@@ -76,77 +70,90 @@ class ClimatizationSettings(GenericSettings):
         ignoreAttributes = ignoreAttributes or []
         LOG.debug('Update Climatization settings from dict')
 
-        if 'targetTemperature_K' in fromDict and fromDict['targetTemperature_K'] is not None:
-            self.targetTemperature_K.setValueWithCarTime(
-                float(fromDict['targetTemperature_K']), lastUpdateFromCar=None, fromServer=True)
+        if 'value' in fromDict:
+            if 'targetTemperature_K' in fromDict['value'] and fromDict['value']['targetTemperature_K'] is not None:
+                self.targetTemperature_K.setValueWithCarTime(
+                    float(fromDict['value']['targetTemperature_K']), lastUpdateFromCar=None, fromServer=True)
+            else:
+                self.targetTemperature_K.enabled = False
+
+            if 'targetTemperature_C' in fromDict['value'] and fromDict['value']['targetTemperature_C'] is not None:
+                self.targetTemperature_C.setValueWithCarTime(
+                    float(fromDict['value']['targetTemperature_C']), lastUpdateFromCar=None, fromServer=True)
+            else:
+                self.targetTemperature_C.enabled = False
+
+            if 'targetTemperature_F' in fromDict['value'] and fromDict['value']['targetTemperature_F'] is not None:
+                self.targetTemperature_F.setValueWithCarTime(
+                    float(fromDict['value']['targetTemperature_F']), lastUpdateFromCar=None, fromServer=True)
+            else:
+                self.targetTemperature_F.enabled = False
+
+            if 'unitInCar' in fromDict['value'] and fromDict['value']['unitInCar']:
+                try:
+                    self.unitInCar.setValueWithCarTime(
+                        ClimatizationSettings.UnitInCar(fromDict['value']['unitInCar']), lastUpdateFromCar=None,
+                        fromServer=True)
+                except ValueError:
+                    self.unitInCar.setValueWithCarTime(ClimatizationSettings.UnitInCar.UNKNOWN,
+                                                       lastUpdateFromCar=None, fromServer=True)
+                    LOG.warning('An unsupported unitInCar: %s was provided,'
+                                ' please report this as a bug', fromDict['value']['unitInCar'])
+            else:
+                self.unitInCar.enabled = False
+
+            if 'climatisationWithoutExternalPower' in fromDict['value']:
+                self.climatisationWithoutExternalPower.setValueWithCarTime(
+                    toBool(fromDict['value']['climatisationWithoutExternalPower']), lastUpdateFromCar=None, fromServer=True)
+            else:
+                self.climatisationWithoutExternalPower.enabled = False
+
+            if 'climatizationAtUnlock' in fromDict['value']:
+                self.climatizationAtUnlock.setValueWithCarTime(
+                    toBool(fromDict['value']['climatizationAtUnlock']), lastUpdateFromCar=None, fromServer=True)
+            else:
+                self.climatizationAtUnlock.enabled = False
+
+            if 'windowHeatingEnabled' in fromDict['value']:
+                self.windowHeatingEnabled.setValueWithCarTime(
+                    toBool(fromDict['value']['windowHeatingEnabled']), lastUpdateFromCar=None, fromServer=True)
+            else:
+                self.windowHeatingEnabled.enabled = False
+
+            if 'zoneFrontLeftEnabled' in fromDict['value']:
+                self.zoneFrontLeftEnabled.setValueWithCarTime(
+                    toBool(fromDict['value']['zoneFrontLeftEnabled']), lastUpdateFromCar=None, fromServer=True)
+            else:
+                self.zoneFrontLeftEnabled.enabled = False
+
+            if 'zoneFrontRightEnabled' in fromDict['value']:
+                self.zoneFrontRightEnabled.setValueWithCarTime(
+                    toBool(fromDict['value']['zoneFrontRightEnabled']), lastUpdateFromCar=None, fromServer=True)
+            else:
+                self.zoneFrontRightEnabled.enabled = False
+
+            if 'zoneRearLeftEnabled' in fromDict['value']:
+                self.zoneRearLeftEnabled.setValueWithCarTime(
+                    toBool(fromDict['value']['zoneRearLeftEnabled']), lastUpdateFromCar=None, fromServer=True)
+            else:
+                self.zoneRearLeftEnabled.enabled = False
+
+            if 'zoneRearRightEnabled' in fromDict['value']:
+                self.zoneRearRightEnabled.setValueWithCarTime(
+                    toBool(fromDict['value']['zoneRearRightEnabled']), lastUpdateFromCar=None, fromServer=True)
+            else:
+                self.zoneRearRightEnabled.enabled = False
         else:
             self.targetTemperature_K.enabled = False
-
-        if 'targetTemperature_C' in fromDict and fromDict['targetTemperature_C'] is not None:
-            self.targetTemperature_C.setValueWithCarTime(
-                float(fromDict['targetTemperature_C']), lastUpdateFromCar=None, fromServer=True)
-        else:
             self.targetTemperature_C.enabled = False
-
-        if 'targetTemperature_F' in fromDict and fromDict['targetTemperature_F'] is not None:
-            self.targetTemperature_F.setValueWithCarTime(
-                float(fromDict['targetTemperature_F']), lastUpdateFromCar=None, fromServer=True)
-        else:
             self.targetTemperature_F.enabled = False
-
-        if 'unitInCar' in fromDict and fromDict['unitInCar']:
-            try:
-                self.unitInCar.setValueWithCarTime(
-                    ClimatizationSettings.UnitInCar(fromDict['unitInCar']), lastUpdateFromCar=None,
-                    fromServer=True)
-            except ValueError:
-                self.unitInCar.setValueWithCarTime(ClimatizationSettings.UnitInCar.UNKNOWN,
-                                                   lastUpdateFromCar=None, fromServer=True)
-                LOG.warning('An unsupported unitInCar: %s was provided,'
-                            ' please report this as a bug', fromDict['unitInCar'])
-        else:
             self.unitInCar.enabled = False
-
-        if 'climatisationWithoutExternalPower' in fromDict:
-            self.climatisationWithoutExternalPower.setValueWithCarTime(
-                toBool(fromDict['climatisationWithoutExternalPower']), lastUpdateFromCar=None, fromServer=True)
-        else:
             self.climatisationWithoutExternalPower.enabled = False
-
-        if 'climatizationAtUnlock' in fromDict:
-            self.climatizationAtUnlock.setValueWithCarTime(
-                toBool(fromDict['climatizationAtUnlock']), lastUpdateFromCar=None, fromServer=True)
-        else:
             self.climatizationAtUnlock.enabled = False
-
-        if 'windowHeatingEnabled' in fromDict:
-            self.windowHeatingEnabled.setValueWithCarTime(
-                toBool(fromDict['windowHeatingEnabled']), lastUpdateFromCar=None, fromServer=True)
-        else:
             self.windowHeatingEnabled.enabled = False
-
-        if 'zoneFrontLeftEnabled' in fromDict:
-            self.zoneFrontLeftEnabled.setValueWithCarTime(
-                toBool(fromDict['zoneFrontLeftEnabled']), lastUpdateFromCar=None, fromServer=True)
-        else:
             self.zoneFrontLeftEnabled.enabled = False
-
-        if 'zoneFrontRightEnabled' in fromDict:
-            self.zoneFrontRightEnabled.setValueWithCarTime(
-                toBool(fromDict['zoneFrontRightEnabled']), lastUpdateFromCar=None, fromServer=True)
-        else:
             self.zoneFrontRightEnabled.enabled = False
-
-        if 'zoneRearLeftEnabled' in fromDict:
-            self.zoneRearLeftEnabled.setValueWithCarTime(
-                toBool(fromDict['zoneRearLeftEnabled']), lastUpdateFromCar=None, fromServer=True)
-        else:
             self.zoneRearLeftEnabled.enabled = False
-
-        if 'zoneRearRightEnabled' in fromDict:
-            self.zoneRearRightEnabled.setValueWithCarTime(
-                toBool(fromDict['zoneRearRightEnabled']), lastUpdateFromCar=None, fromServer=True)
-        else:
             self.zoneRearRightEnabled.enabled = False
 
         super().update(fromDict=fromDict, ignoreAttributes=(ignoreAttributes + [
