@@ -26,29 +26,34 @@ class PlugStatus(GenericStatus):
         ignoreAttributes = ignoreAttributes or []
         LOG.debug('Update Plug status from dict')
 
-        if 'plugConnectionState' in fromDict and fromDict['plugConnectionState']:
-            try:
-                self.plugConnectionState.setValueWithCarTime(
-                    PlugStatus.PlugConnectionState(fromDict['plugConnectionState']), lastUpdateFromCar=None,
-                    fromServer=True)
-            except ValueError:
-                self.plugConnectionState.setValueWithCarTime(PlugStatus.PlugConnectionState.UNKNOWN,
-                                                             lastUpdateFromCar=None, fromServer=True)
-                LOG.warning('An unsupported plugConnectionState: %s was provided,'
-                            ' please report this as a bug', fromDict['plugConnectionState'])
+        if 'value' in fromDict:
+            if 'plugConnectionState' in fromDict['value'] and fromDict['value']['plugConnectionState']:
+                try:
+                    self.plugConnectionState.setValueWithCarTime(
+                        PlugStatus.PlugConnectionState(fromDict['value']['plugConnectionState']), lastUpdateFromCar=None,
+                        fromServer=True)
+                except ValueError:
+                    self.plugConnectionState.setValueWithCarTime(PlugStatus.PlugConnectionState.UNKNOWN,
+                                                                 lastUpdateFromCar=None, fromServer=True)
+                    LOG.warning('An unsupported plugConnectionState: %s was provided,'
+                                ' please report this as a bug', fromDict['value']['plugConnectionState'])
+            else:
+                self.plugConnectionState.enabled = False
+
+            if 'plugLockState' in fromDict['value'] and fromDict['value']['plugLockState']:
+                try:
+                    self.plugLockState.setValueWithCarTime(PlugStatus.PlugLockState(fromDict['value']['plugLockState']),
+                                                           lastUpdateFromCar=None, fromServer=True)
+                except ValueError:
+                    self.plugLockState.setValueWithCarTime(PlugStatus.PlugLockState.UNKNOWN,
+                                                           lastUpdateFromCar=None, fromServer=True)
+                    LOG.warning('An unsupported plugLockState: %s was provided,'
+                                ' please report this as a bug', fromDict['value']['plugLockState'])
+            else:
+                self.plugLockState.enabled = False
+
         else:
             self.plugConnectionState.enabled = False
-
-        if 'plugLockState' in fromDict and fromDict['plugLockState']:
-            try:
-                self.plugLockState.setValueWithCarTime(PlugStatus.PlugLockState(fromDict['plugLockState']),
-                                                       lastUpdateFromCar=None, fromServer=True)
-            except ValueError:
-                self.plugLockState.setValueWithCarTime(PlugStatus.PlugLockState.UNKNOWN,
-                                                       lastUpdateFromCar=None, fromServer=True)
-                LOG.warning('An unsupported plugLockState: %s was provided,'
-                            ' please report this as a bug', fromDict['plugLockState'])
-        else:
             self.plugLockState.enabled = False
 
         super().update(fromDict=fromDict, ignoreAttributes=(
